
function [x, y, z] = readNexus2D(hfile)

% NAME
%
%   readNexus2D -- read Nexus data (in 2 dimension)
%
% SYNOPSIS
%
%   [x, y, z] = readNexus1D(hfile)
%
% INPUTS
%
%   hfile  - Nexus file name
%
% OUTPUT
%
%   x - the x axis values
%   y - the y axis values
%   z - the z values
%
% OUTPUT FORMAT
%
%       x,y - numeric data array (one dimensional)
%       z   - numeric data array (two dimensional)
% --------------------------------------------------------------------------------
% based on the work of
% Todd Mitchell mailto:mitchell@atmos.washington.edu 
% and
% H. Motteler, 22 Nov 00 ('hdtools')
% modified for Nexus by
% F. Ott, Lab. Lon Brillouin, CEA Saclay
%

access_mode = 'rdonly';
sd_id = hdfsd( 'start', hfile, access_mode );
if sd_id == -1
  error('NXS sdstart failed')
end

% general info about file contents
[ndatasets, nglobal_attr, status] = hdfsd('fileinfo',sd_id);
if status == -1
  error('NXS sdfileinfo failed')
end

% loop on SDS indices and read SDS's
for sds_index = 0 : ndatasets-1  % sds_index icnt begins at zero because HDF counts from 0, not 1.
  sds_id = hdfsd( 'select', sd_id, sds_index );
  [ds_name, ds_ndims, ds_dims, ds_type, ds_atts, stat] = hdfsd('getinfo',sds_id);
  ds_start = zeros(1,ds_ndims);
  ds_stride = []; 
  ds_edges = ds_dims; 
  [ds_data, status] = hdfsd('readdata',sds_id,ds_start,ds_stride,ds_edges); % "ds_data" is the data.
  % are we dealing with an axis or with the signal
  attr_index = hdfsd('findattr',sds_id,'axis');  % is there an axis attribute ?
  if attr_index~=-1
     [data,status] = hdfsd('readattr',sds_id,attr_index);
     if data==1, 
         x=ds_data;
     end;
     if data==2, 
         y=ds_data;
     end;     
  end
  attr_index = hdfsd('findattr',sds_id,'signal'); % is there an axis attribute ?
  if attr_index~=-1
     [data,status] = hdfsd('readattr',sds_id,attr_index);
     if data==1, 
         z=ds_data;
     end;
  end
end 


% close the file
status = hdfsd('end',sd_id);
if sd_id == -1
  error('NXS sdend failed')
end

